#!/usr/bin/env python3


from libervia.web.server.constants import Const as C
from twisted.internet import defer
from libervia.backend.core.log import getLogger
from libervia.backend.tools.common import date_utils

"""creation of new events"""

name = "event_new"
access = C.PAGES_ACCESS_PROFILE
template = "event/create.html"
log = getLogger(__name__)


async def on_data_post(self, request):
    request_data = self.get_r_data(request)
    profile = self.get_profile(request)
    title, location, body, date, main_img, bg_img = self.get_posted_data(
        request, ("name", "location", "body", "date", "main_image", "bg_image")
    )
    timestamp = date_utils.date_parse(date)
    data = {"name": title, "description": body, "location": location}

    for value, var in ((main_img, "image"), (bg_img, "background-image")):
        value = value.strip()
        if not value:
            continue
        if not value.startswith("http"):
            self.page_error(request, C.HTTP_BAD_REQUEST)
        data[var] = value
    data["register"] = C.BOOL_TRUE
    node = await self.host.bridge_call("event_create", timestamp, data, "", "", "", profile)
    log.info("Event node created at {node}".format(node=node))

    request_data["post_redirect_page"] = (self.get_page_by_name("event_admin"), "@", node)
    return C.POST_NO_CONFIRM
